# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/01 17:01
@Description: Description
@File: system_env_api.py
"""
from api_requester.http.eclinical_requests import *


class CommonSystemEnvApi:
    """
    The CommonSystemEnvApi was generated by Generator from the SystemEnvController.java file.
    """

    @get('/system/env')
    def get_current_system_env_api(self, *args, **kwargs): ...

    @get('/system/env/list')
    def sponsor_env_list_api(self, *args, **kwargs): ...

    @put('/system/env/{envId}/role/{roleId}')
    def switch_env_api(self, *args, **kwargs): ...
