# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/01 17:01
@Description: Description
@File: system_env_service.py
"""
from api_requester.core.common.api.system_env_api import CommonSystemEnvApi


class CommonSystemEnvService(CommonSystemEnvApi):
    """
    The CommonSystemEnvService was generated by Generator from the SystemEnvController.java file.
    """

    def __init__(self):
        CommonSystemEnvApi.__init__(self)

    def get_current_system_env(self):
        return self.get_current_system_env_api()

    def sponsor_env_list(self):
        return self.sponsor_env_list_api()

    def switch_env(self, env_id: int, role_id: int):
        return self.switch_env_api(url_kwargs=dict(envId=env_id, roleId=role_id))
