# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/26 19:01
@Description: Description
@File: auth_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminAuthApi:
    """
    The AdminAuthApi was generated by Generator from the AuthController.java file.
    """
    
    @post('/auth')
    def create_authentication_token_api(self, *args, **kwargs): ...
    
    @get('/refresh')
    def refresh_and_get_authentication_token_api(self, *args, **kwargs): ...
    
    @get('/auth/logout')
    def logout_api(self, *args, **kwargs): ...
    
    @get('/auth/all/logout')
    def logout_all_api(self, *args, **kwargs): ...
    
    @get('/me')
    def me_api(self, *args, **kwargs): ...
    
    @post('/auth/sso/token')
    def auth_sso_token_api(self, *args, **kwargs): ...
    